#[repr(transparent)]pub struct Keylock(pub u32);Expand description
Only reset in case of full IC reset
Tuple Fields
0: u32Implementations
Sourceimpl Keylock
impl Keylock
Sourcepub const fn key0(&self) -> u8
pub const fn key0(&self) -> u8
“10:Write access to KEY0MASK, KEYENABLE.KEY0 and KEYRESET.KEY0 is allowed. 00, 01, 11:Write access to KEY0MASK, KEYENABLE.KEY0 and KEYRESET.KEY0 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn set_key0(&mut self, val: u8)
pub const fn set_key0(&mut self, val: u8)
“10:Write access to KEY0MASK, KEYENABLE.KEY0 and KEYRESET.KEY0 is allowed. 00, 01, 11:Write access to KEY0MASK, KEYENABLE.KEY0 and KEYRESET.KEY0 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn key1(&self) -> u8
pub const fn key1(&self) -> u8
“10:Write access to KEY1MASK, KEYENABLE.KEY1 and KEYRESET.KEY1 is allowed. 00, 01, 11:Write access to KEY1MASK, KEYENABLE.KEY1 and KEYRESET.KEY1 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn set_key1(&mut self, val: u8)
pub const fn set_key1(&mut self, val: u8)
“10:Write access to KEY1MASK, KEYENABLE.KEY1 and KEYRESET.KEY1 is allowed. 00, 01, 11:Write access to KEY1MASK, KEYENABLE.KEY1 and KEYRESET.KEY1 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn key2(&self) -> u8
pub const fn key2(&self) -> u8
“10:Write access to KEY2MASK, KEYENABLE.KEY2 and KEYRESET.KEY2 is allowed. 00, 01, 11:Write access to KEY2MASK, KEYENABLE.KEY2 and KEYRESET.KEY2 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn set_key2(&mut self, val: u8)
pub const fn set_key2(&mut self, val: u8)
“10:Write access to KEY2MASK, KEYENABLE.KEY2 and KEYRESET.KEY2 is allowed. 00, 01, 11:Write access to KEY2MASK, KEYENABLE.KEY2 and KEYRESET.KEY2 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn key3(&self) -> u8
pub const fn key3(&self) -> u8
“10:Write access to KEY3MASK, KEYENABLE.KEY3 and KEYRESET.KEY3 is allowed. 00, 01, 11:Write access to KEY3MASK, KEYENABLE.KEY3 and KEYRESET.KEY3 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”
Sourcepub const fn set_key3(&mut self, val: u8)
pub const fn set_key3(&mut self, val: u8)
“10:Write access to KEY3MASK, KEYENABLE.KEY3 and KEYRESET.KEY3 is allowed. 00, 01, 11:Write access to KEY3MASK, KEYENABLE.KEY3 and KEYRESET.KEY3 is NOT allowed. Important Note : Once this field is written with a value different from ‘10’, its value can no longer be modified until un Power On Reset occurs.”