nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
PUF Status register

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn busy(&self) -> bool

Indicates that operation is in progress

pub const fn set_busy(&mut self, val: bool)

Indicates that operation is in progress

pub const fn success(&self) -> bool

Last operation was successful

pub const fn set_success(&mut self, val: bool)

Last operation was successful

pub const fn error(&self) -> bool

PUF is in the Error state and no operations can be performed

pub const fn set_error(&mut self, val: bool)

PUF is in the Error state and no operations can be performed

pub const fn keyinreq(&self) -> bool

Request for next part of key

pub const fn set_keyinreq(&mut self, val: bool)

Request for next part of key

pub const fn keyoutavail(&self) -> bool

Next part of key is available

pub const fn set_keyoutavail(&mut self, val: bool)

Next part of key is available

pub const fn codeinreq(&self) -> bool

Request for next part of AC/KC

pub const fn set_codeinreq(&mut self, val: bool)

Request for next part of AC/KC

pub const fn codeoutavail(&self) -> bool

Next part of AC/KC is available

pub const fn set_codeoutavail(&mut self, val: bool)

Next part of AC/KC is available